Signals
=======

Django Site Utils can be extended by hooking your own applications into the
signals it provides.

More documentation on signals will be available in a future release, as the
signals are defined.
